@@ -5,7 +5,7 @@ use warnings;
 use base 'My::Builder';
 
 use File::Spec::Functions qw(catdir catfile rel2abs);
-use File::Spec;
+use File::Spec qw(devnull);
 use File::Glob qw(glob);
 use File::Copy;
 use Config;
@@ -25,6 +25,8 @@ sub build_binaries {
   my $dir_opengl_lib = ($d && -d $d && $d ne '/usr/lib') ? $d : '';
   $d = $self->run_stdout2str(qw[pkg-config --variable=includedir gl]);
   my $dir_opengl_inc = ($d && -d $d && $d ne '/usr/include') ? $d : '';
+  $d = $self->run_stdout2str(qw[pkg-config --variable=prefix gtk+-2.0]);
+  my $dir_gtk = ($d && -d $d) ? $d : '';
 
   my $dir_mot_inc = ''; # Xm/Xm.h (do not know where to get a sane default)
   $dir_mot_inc  ||= '/usr/local/include'         if (-f '/usr/local/include/Xm/Xm.h');
@@ -72,48 +74,19 @@ sub build_binaries {
     print STDERR "extra_cflags=$extra_cflags\n";
     print STDERR "extra_lflags=$extra_lflags\n";
   }
-
-  my %list = (
-    gtk        => 'gtk+-2.0',
-    gtk3       => 'gtk+-3.0',
-    gtkx11     => 'gtk+-x11-2.0',
-    gdk        => 'gdk-2.0',
-    gdk3       => 'gdk-3.0',
-    gdkx11     => 'gdk-x11-2.0',
-    gtkprint   => 'gtk+-unix-print-2.0',
-    webkit     => 'webkit-1.0',
-    cairo      => 'cairo',
-    pango      => 'pango',
-    pangox     => 'pangox',
-    pangocairo => 'pangocairo',
-    freetype2  => 'freetype2',
-    x11        => 'x11',
-    xext       => 'xext',
-    xp         => 'xp',
-    xm         => 'xm',
-    xmu        => 'xmu',
-  );
-
   my %has;
-  my %has_details;
-  for (sort keys %list) {
-    my $v = $self->run_stdout2str(qw[pkg-config --modversion], $list{$_}) || '';
-    my $p = $self->run_stdout2str(qw[pkg-config --variable=prefix], $list{$_}) || '';
-    $has{$_} = $v ? 1 : 0;
-    $has_details{$_} = { version=>$v, prefix=>$p };    
-    printf STDERR ("mod:% 20s version:% 9s prefix:%s\n", $list{$_}, $v, $p) if $self->notes('build_debug_info');
-  }
 
-  #detect pkg-config
-  my $pkgcfg = $self->run_stdout2str(qw[pkg-config --version]);
-  $has{'pkg-config'} = $pkgcfg ? 1 : 0;
-  $has_details{'pkg-config'} = { version=>$pkgcfg, prefix=>$self->run_stdout2str(qw[which pkg-config]) };
-  
+  $has{gtk}     = `pkg-config --modversion gtk+-2.0 2>/dev/null` ? 1 : 0;        #iupgtk
+  $has{gtkx11}  = `pkg-config --modversion gtk+-x11-2.0 2>/dev/null` ? 1 : 0;
+  $has{gdk}     = `pkg-config --modversion gdk-2.0 2>/dev/null` ? 1 : 0;        #cdgdk
+  $has{gdkx11}  = `pkg-config --modversion gdk-x11-2.0 2>/dev/null` ? 1 : 0;
+  $has{cairo}   = `pkg-config --modversion cairo 2>/dev/null` ? 1 : 0;                 #cdcairo
+  $has{pango}   = `pkg-config --modversion pango 2>/dev/null` ? 1 : 0;                #cdcairo
+  #$has{pangox}  = `pkg-config --modversion pangox 2>/dev/null` ? 1 : 0;
+
   $has{l_gtk}   = $has{gtk}    && $self->check_lib( [] , `pkg-config --cflags gtk+-2.0 2>/dev/null`,     `pkg-config --libs gtk+-2.0 2>/dev/null`);
-  $has{l_gtk3}  = $has{gtk3}   && $self->check_lib( [] , `pkg-config --cflags gtk+-3.0 2>/dev/null`,     `pkg-config --libs gtk+-3.0 2>/dev/null`);
   $has{l_gtkx11}= $has{gtkx11} && $self->check_lib( [] , `pkg-config --cflags gtk+-x11-2.0 2>/dev/null`, `pkg-config --libs gtk+-x11-2.0 2>/dev/null`);
   $has{l_gdk}   = $has{gdk}    && $self->check_lib( [] , `pkg-config --cflags gdk-2.0 2>/dev/null`,      `pkg-config --libs gdk-2.0 2>/dev/null`);
-  $has{l_gdk3}  = $has{gdk3}   && $self->check_lib( [] , `pkg-config --cflags gdk-3.0 2>/dev/null`,      `pkg-config --libs gdk-3.0 2>/dev/null`);
   $has{l_gdkx11}= $has{gdkx11} && $self->check_lib( [] , `pkg-config --cflags gdk-x11-2.0 2>/dev/null`,  `pkg-config --libs gdk-x11-2.0 2>/dev/null`);
   $has{l_cairo} = $has{cairo}  && $self->check_lib( [] , `pkg-config --cflags cairo 2>/dev/null`,        `pkg-config --libs cairo 2>/dev/null`);
   $has{l_pango} = $has{pango}  && $self->check_lib( [] , `pkg-config --cflags pango 2>/dev/null`,        `pkg-config --libs pango 2>/dev/null`);
@@ -128,7 +101,6 @@ sub build_binaries {
   $has{l_GL}    = $self->check_lib( 'GL',   $extra_cflags, $extra_lflags );
   $has{l_GLU}   = $self->check_lib( 'GLU',  $extra_cflags, $extra_lflags . ' -lGL -lm' );
   $has{l_glut}  = $self->check_lib( 'glut', $extra_cflags, $extra_lflags );
-  $has{'l_stdc++'} = $self->check_lib( 'stdc++', $extra_cflags, $extra_lflags );
 
   $has{Xm}      = $self->check_header('Xm/Xm.h',   $extra_cflags);
   $has{Xlib}    = $self->check_header('X11/Xlib.h',$extra_cflags); #iupgl cdx11
@@ -136,9 +108,32 @@ sub build_binaries {
   $has{glu}     = $self->check_header('GL/glu.h',  $extra_cflags);
   $has{gl}      = $self->check_header('GL/gl.h',   $extra_cflags);
 
-  #kind of a special hack
-  $has{freetype} = $self->check_header('ft2build.h', `pkg-config --cflags gtk+-2.0 gdk-2.0 2>/dev/null`) ||
-                   $self->check_header('ft2build.h', `pkg-config --cflags gtk+-3.0 gdk-3.0 2>/dev/null`);
+  if ($self->notes('build_debug_info')) {
+    #$has{fftw3}   = $self->check_header('fftw3.h',   $extra_cflags); #im_fftw3 = http://www.fftw.org/
+    #$has{wmsdk}   = $self->check_header('wmsdk.h');                  #im_wmv
+    #$has{ecw}     = $self->check_header('NCSECWClient.h');           #im_format_ecw = ECW (Enhanced Compression Wavelet) format
+    #$has{XxXxX}   = $self->check_header('XxXxX/XxXxX.h');            #non existing header
+    print STDERR "Has: $has{$_} - $_\n" foreach (sort keys %has);
+
+    print STDERR "Brute force lookup:\n";
+    my $re = qr/\/(Xlib.h|Xm.h|gtk.h|glu.h|glut.h|gl.h|gtkprintunixdialog.h|libX11\.[^\d]*|libGL\.[^\d]*|libXm\.[^\d]*)$/;
+    print STDERR "[/usr    ] $_\n" foreach ($self->find_file('/usr', $re));
+    print STDERR "[/lib    ] $_\n" foreach ($self->find_file('/usr', $re));
+    print STDERR "[/opt    ] $_\n" foreach ($self->find_file('/opt', $re));
+    print STDERR "[/sw     ] $_\n" foreach ($self->find_file('/sw', $re));
+    print STDERR "[/System ] $_\n" foreach ($self->find_file('/System', $re));
+    print STDERR "[/Library] $_\n" foreach ($self->find_file('/Library', $re));
+    print STDERR "[/Network] $_\n" foreach ($self->find_file('/Network', $re));
+
+    print STDERR "Dumping some pkg-info:\n";
+    print STDERR "[gtk2 cflags] " . $self->run_stdout2str(qw[pkg-config --cflags gtk+-2.0]) . "\n";
+    print STDERR "[gtk2 libs  ] " . $self->run_stdout2str(qw[pkg-config --libs gtk+-2.0]) . "\n";
+    for my $pkg (qw[gtk+-2.0 gl glu glut x11 xt xext xmu]) {
+      print STDERR "[prefix     $pkg] " . $self->run_stdout2str(qw[pkg-config --variable=prefix], $pkg) . "\n";
+      print STDERR "[libdir     $pkg] " . $self->run_stdout2str(qw[pkg-config --variable=libdir], $pkg) . "\n";
+      print STDERR "[includedir $pkg] " . $self->run_stdout2str(qw[pkg-config --variable=includedir], $pkg) . "\n";
+    }
+  }
 
   my @x11_libs; # just base X11 libs
   push(@x11_libs, 'X11')  if $has{l_X11};
@@ -148,79 +143,36 @@ sub build_binaries {
   push(@opengl_libs, 'GL')  if $has{l_GL};
   push(@opengl_libs, 'GLU') if $has{l_GLU};
 
-  my @imtargets;
-  my @cdtargets;
-  my @iuptargets;
-  
-  #possible targets:  im im_process im_jp2 im_fftw im_capture im_avi im_wmv
-  #possible targets:  cd_zlib cd_freetype cd_ftgl cd cd_pdflib cdpdf cdgl cdcontextplus cdcairo
-  #possible targets:  iup iupcd iupcontrols iup_pplot iup_mglplot iupgl iupim iupimglib iupweb iuptuio iup_plot
-  
-  if ($self->notes('is_devel_cvs_version')) {
-    ### DEVEL BUILD ###
-    @imtargets  = qw[im im_process im_jp2 im_fftw im_capture];
-    @cdtargets  = qw[cd_zlib cd_freetype cd_ftgl cd cd_pdflib cdpdf cdgl]; #xxx add cdcontextplus
-    @iuptargets = qw[iup iupcd iupcontrols iupmatrixex iup_pplot iup_mglplot iupgl iupglcontrols iup_scintilla iupim iupimglib iupweb iuptuio iup_plot];
-  }
-  else {
-    @imtargets  = qw[im];
-    @cdtargets  = qw[cd_zlib cd_freetype cd_ftgl cd];
-    @iuptargets = qw[iup iupcd iupcontrols iupmatrixex iup_pplot iup_mglplot iupgl iupglcontrols iup_scintilla iupim iupimglib iup_plot];
-    #if ($^O eq 'openbsd') {
-    #  warn "###WARN### skipping im_process on OpenBSD";
-    #  @imtargets = grep { $_ !~ /^im_process$/ } @imtargets;
-    #}
-    #if ($^O eq 'solaris') {
-    #  warn "###WARN### skipping iuptuio on Solaris";
-    #  @iuptargets = grep { $_ !~ /^iuptuio$/ } @iuptargets;
-    #}
-
-    if ($^O eq 'solaris') {
-      warn "###WARN### skipping iup_mglplot on Solaris (fails to compile)";
-      @iuptargets = grep { $_ !~ /^iup_mglplot$/ } @iuptargets;
-    }
+  #possible targets: im im_process im_jp2 im_fftw im_capture im_avi im_wmv im_fftw3 im_ecw
+  my @imtargets = qw[im im_process im_jp2 im_fftw];
+  if ($^O eq 'openbsd') {
+    warn "###WARN### Skipping im_process on OpenBSD"; # xxx TODO xxx
+    @imtargets = grep { $_ !~ /^(im_process)$/ } @imtargets;
   }
 
-  unless ($has{l_GL} && $has{l_GLU} && $has{gl} && $has{glx} && $has{glu}) {
-    warn "###WARN### OpenGL libraries not found or not complete\n";
-    warn "- required headers: GL/gl.h GL/glx.h GL/glu.h\n";
-    warn "- required libraries: libGL libGLU\n";
-    my $skip = $ENV{TRAVIS} ? 'y' : $self->prompt("Skip OpenGL related IUP/CD components?", 'y');
-    if (lc($skip) eq 'y') {
-      @cdtargets  = grep { $_ !~ /^(cd_ftgl|cdgl)$/ } @cdtargets;
-      @iuptargets = grep { $_ !~ /^(iup_mglplot|iup_plot|iupglcontrols|iupgl)$/ } @iuptargets;
-    }
-  }
-  @iuptargets = grep { $_ !~ /^(iupweb)$/ } @iuptargets unless $has{webkit};
+  #possible targets: cd_freetype cd_ftgl cd cd_pdflib cdpdf cdgl cdcontextplus cdcairo
+  my @cdtargets = qw[cd_freetype cd_ftgl cd cd_pdflib cdpdf cdgl];
+  @cdtargets = grep { $_ !~ /^(cd_ftgl|cdgl)$/ } @cdtargets unless $has{l_GLU};
+
+  #possible targets: iup iupcd iupcontrols iupim iupimglib iup_pplot iupgl
+  my @iuptargets = qw[iup iupcd iupcontrols iupim iupimglib iup_pplot iupgl];
+  @iuptargets = grep { $_ !~ /^(iupgl)$/ } @iuptargets unless $has{glx};
 
   #store debug info into ConfigData
-  $self->config_data('info_has', \%has);
-  $self->config_data('info_lib_details', \%has_details);
-  $self->config_data('info_imtargets', \@imtargets);
-  $self->config_data('info_cdtargets', \@cdtargets);
-  $self->config_data('info_iuptargets', \@iuptargets);
+  $self->config_data('debug_has', \%has);
+  $self->config_data('debug_imtargets', \@imtargets);
+  $self->config_data('debug_cdtargets', \@cdtargets);
+  $self->config_data('debug_iuptargets', \@iuptargets);
 
   my @makeopts  = qw[NO_DYNAMIC=Yes USE_NODEPEND=Yes];
   #my @makeopts  = qw[NO_STATIC=Yes USE_NODEPEND=Yes];
   
-  #On solaris, some tools like 'ar' are not in the default PATH, but in /usr/???/bin    
-  if ($^O eq 'solaris') {
-    my ($ar, $ranlib);
-    for (qw[/usr/ccs/bin /usr/xpg4/bin /usr/sfw/bin /usr/xpg6/bin /usr/gnu/bin /opt/gnu/bin /usr/bin]) {
-      $ar = "$_/ar" if (!$ar && -x "$_/ar");
-      $ranlib = "$_/ranlib" if (!$ranlib && -x "$_/ranlib");
-    }
-    push @makeopts, "AR=$ar" if $ar;
-    push @makeopts, "RANLIB=$ranlib" if $ranlib;
-  }
-
   #choose GUI subsystem, priorities if multiple subsystems detected: 1. GTK, 2. X11/Motif
   my @libs;
   my @build_opts;
-  my $build_target;
-
-  push(@build_opts, 'GTK3') if ($has{gtk3} && $has{gdk3} && $has{cairo} && $has{Xlib});
-  push(@build_opts, 'GTK2') if ($has{gtk} && $has{gdk} && $has{cairo} && $has{Xlib});
+  my $build_target = '';
+  
+  push(@build_opts, 'GTK2') if $has{gtk};
   push(@build_opts, 'X11/Motif') if ($has{Xlib} && $has{Xm});
 
   if (scalar(@build_opts) == 1) {
@@ -231,86 +183,22 @@ sub build_binaries {
     my $msg = "\nYou have the following build options available:\n" .
               join("\n", map ($n++ . ") $_", @build_opts)) .
 	      "\nWhat do you wanna build?";
-    my $i = $ENV{TRAVIS} ? 1 : $self->prompt($msg, 1);
+    my $i = $self->prompt($msg, 1);
     $build_target = $build_opts[$i-1];
     die "###ERROR### Wrong selection!" unless $build_target;
   }
   else {
-    warn "###WARNING### No supported GUI subsystem detected!\n";
+    die "###FATAL### No supported GUI subsystem (Win32, GTK, X11/Motif) detected! (trying X11)";
+    #warn "###WARN### No supported GUI subsystem (Win32, GTK, X11/Motif) detected! (trying X11)";
+    $success = 0;
+    $build_target = 'X11/Motif';
   }
 
-  if ($self->notes('build_debug_info') || ( !$build_target && $ENV{AUTOMATED_TESTING} ) ) {
-    foreach (sort keys %has) {
-      my $msg = "has: $has{$_} - $_";
-      $msg .= "; version=" . $has_details{$_}->{version} if $has_details{$_}->{version};
-      $msg .= "; prefix="  . $has_details{$_}->{prefix}  if $has_details{$_}->{prefix};
-      print STDERR $msg, "\n";
-    }
-
-    print STDERR "Dumping some pkg-info:\n";
-    print STDERR "[gtk2 cflags] " . $self->run_stdout2str(qw[pkg-config --cflags gtk+-2.0]) . "\n";
-    print STDERR "[gtk2 libs  ] " . $self->run_stdout2str(qw[pkg-config --libs gtk+-2.0]) . "\n";
-    print STDERR "[gtk3 cflags] " . $self->run_stdout2str(qw[pkg-config --cflags gtk+-3.0]) . "\n";
-    print STDERR "[gtk3 libs  ] " . $self->run_stdout2str(qw[pkg-config --libs gtk+-3.0]) . "\n";
-    for my $pkg (qw[gtk+-2.0 gtk+-3.0 gl glu glut x11 xt xext xmu]) {
-      print STDERR "[prefix     $pkg] " . $self->run_stdout2str(qw[pkg-config --variable=prefix], $pkg) . "\n";
-      print STDERR "[libdir     $pkg] " . $self->run_stdout2str(qw[pkg-config --variable=libdir], $pkg) . "\n";
-      print STDERR "[includedir $pkg] " . $self->run_stdout2str(qw[pkg-config --variable=includedir], $pkg) . "\n";
-    }
-
-    print STDERR "Brute force lookup:\n";
-    my $re = qr/\/(Xlib.h|Xm.h|gtk.h|cairo.h|glu.h|glut.h|gl.h|freetype.h|gtkprintunixdialog.h|jasper.h|jas_image.h|lib(X11|GL|Xm|freetype)\.[^\d]*)$/;
-    print STDERR "[/usr    ] $_\n" foreach ($self->find_file('/usr', $re));
-    print STDERR "[/lib    ] $_\n" foreach ($self->find_file('/usr', $re));
-    print STDERR "[/opt    ] $_\n" foreach ($self->find_file('/opt', $re));
-    print STDERR "[/sw     ] $_\n" foreach ($self->find_file('/sw', $re));
-    print STDERR "[/System ] $_\n" foreach ($self->find_file('/System', $re));
-    print STDERR "[/Library] $_\n" foreach ($self->find_file('/Library', $re));
-    print STDERR "[/Network] $_\n" foreach ($self->find_file('/Network', $re));
-  }
-  
-  unless ($build_target) {
-    warn <<'MARKER';
-###FATAL### No supported GUI subsystem (GTK3, GTK2, X11/Motif) detected! (gonna exit)
-### for GTK3 you need: gtk+-3.0, gdk-3.0, cairo + X11/Xlib.h
-### for GTK2 you need: gtk+-2.0, gdk-2.0, cairo + X11/Xlib.h
-### for X11/Motif you need: -lXm, -lX11 + Xm/Xm.h, X11/Xlib.h
-### 
-### on Debian/Ubuntu you need to install: 
-###  $ aptitude install libgtk2.0-dev libcairo2-dev libx11-dev libglu-dev freeglut3-dev
-### 
-### on RedHat/CentOS/Fedora you need to install: 
-###  $ yum install gtk2-devel cairo-devel libX11-devel libGLU-devel freeglut-devel
-###
-### on FreeBSD you need to install:
-###  $ pkg install gtk2 cairo freeglut
-###
-MARKER
-    die;
-  }
-  
-  $self->config_data('info_gui_driver', $build_target);
-
-  print STDERR "Build target=", ($build_target || ''), "\n";
-  if ($build_target eq 'GTK2' || $build_target eq 'GTK3') {
+  print STDERR "Build target=", ($build_target || ''), "\n";  
+  if ($build_target eq 'GTK2') {
     push(@makeopts, 'USE_GTK=Yes');
-    push(@makeopts, 'USE_GTK3=Yes') if ($build_target eq 'GTK3');
-    push(@makeopts, 'USE_GDK=Yes');
-    push(@makeopts, 'USE_PKGCONFIG=Yes');
-    
-    #xxx maybe remove in the future (temporary fix)
-    my $gtk_base = ($build_target eq 'GTK2') ?
-                   $self->run_stdout2str(qw[pkg-config --variable=prefix gtk+-2.0]) :
-                   $self->run_stdout2str(qw[pkg-config --variable=prefix gtk+-3.0]);
-    push(@makeopts, "GTK_BASE=$gtk_base") if $gtk_base;
-    push(@makeopts, "GTK=$gtk_base") if $gtk_base;
-
-    #handle existing freetype
-    if ($has{freetype}) { #xxx TODO: later replace with $has{freetype2}
-      @cdtargets = grep { $_ !~ /^(cd_freetype)$/ } @cdtargets;
-    }
-
     #detected libs
+#xxx    push(@makeopts, "GTK_BASE=$dir_gtk") if $dir_gtk;
     push(@makeopts, "X11_LIBS=" . join(' ', @x11_libs));
     push(@makeopts, "X11_LIB=$dir_x11_lib") if $dir_x11_lib;
     push(@makeopts, "X11_INC=$dir_x11_inc") if $dir_x11_inc;
@@ -320,15 +208,12 @@ MARKER
 
     push(@libs, @opengl_libs);
     #Note: $extra_?flags will be stored into ConfigData - they are not used for building
-    my @mods = ($build_target eq 'GTK2') ?
-               qw[gtk+-2.0 gdk-2.0 pango cairo] :
-               qw[gtk+-3.0 gdk-3.0 pango cairo];
+    my @mods = qw[gtk+-2.0 gdk-2.0 pango cairo];
     $extra_cflags = $self->run_stdout2str(qw[pkg-config --cflags], @mods) . " $extra_cflags";
     $extra_lflags = $self->run_stdout2str(qw[pkg-config --libs], @mods) . " $extra_lflags";
   }
   elsif ($build_target eq 'X11/Motif') {
     push(@makeopts, 'USE_X11=Yes');
-    push(@makeopts, 'USE_MOTIF=Yes');
     #additional X11 related libs
     push(@x11_libs, 'Xp')   if $has{l_Xp};
     push(@x11_libs, 'Xt')   if $has{l_Xt};
@@ -349,18 +234,13 @@ MARKER
   else {
     die "###ERROR### Wrong build target '$build_target!";
   }
-  
-  #extra options for iup/imglib
-  push(@makeopts, 'USE_IUP_IMGLIB_LARGE=1') if $self->notes('build_large_imglib');
-  
-  if ($Config{cc} eq 'cc') {
-    # fix for: https://rt.cpan.org/Public/Bug/Display.html?id=94615
-    push(@makeopts, 'CC=cc', 'CPPC=c++');
-  }
 
   #do the job
-  $success = $self->build_via_tecmake($build_out, $srcdir, \@makeopts, \@iuptargets, \@cdtargets, \@imtargets);
-  warn "###MAKE FAILED###" unless $success;
+  print STDERR "Gonna make these targets: " . join(' ', @iuptargets, @cdtargets, @imtargets) . "\n";
+  unless ($self->build_via_tecmake($build_out, $srcdir, \@makeopts, \@iuptargets, \@cdtargets, \@imtargets)) {
+    warn "###MAKE FAILED###";
+    $success = 0;
+  }
 
   #make a list of libs necessary to link with IUP and related libraries
   my %seen;
@@ -372,7 +252,6 @@ MARKER
     $success = 0;
   }
   foreach (@gl_l) {
-    print STDERR "Created lib: $_\n" if $self->notes('build_debug_info');
     if ($_ =~ /lib([a-zA-Z0-9\_\-\.]*?)\.(so|dylib|bundle|a|dll\.a)$/) {
       $seen{$1} = 1;
     }
@@ -382,27 +261,35 @@ MARKER
     }
   }
 
-  push(@libs, 'stdc++') if $has{'l_stdc++'}; # -lstdc++ needed by Linux (at least)
-  my @iuplibs = $self->sort_libs(keys %seen);
-  $self->config_data('iup_libs', {map {$_=>1} @iuplibs} );
-  $self->config_data('linker_libs', [@iuplibs, @libs] );
+  push(@libs, 'stdc++'); # -lstdc++ needed by Linux (at least)
+
+  print STDERR "Output libs: $_\n" foreach (sort keys %seen);
+  @libs = ( $self->sort_libs(keys %seen), @libs );
+
+  $self->config_data('linker_libs', \@libs);
   $self->config_data('extra_cflags', $extra_cflags);
   $self->config_data('extra_lflags', $extra_lflags);
 
-  print STDERR "Build finished!\n";
-  return $success;
+  die "###BUILD ABORTED###" unless $success;
+  print STDERR "Build finished sucessfully!\n";
+
+  #DEBUG: fail intentionally here if you want to see build details from cpan testers
+  #die "Intentionally failing";
 };
 
 sub build_via_tecmake {
   my ($self, $build_out, $srcdir, $mopts, $iuptgs, $cdtgs, $imtgs) = @_;
   $srcdir ||= 'src';
   my $prefixdir = rel2abs($build_out);
-
   my $make = $self->notes('gnu_make') || $self->get_make;
   die "###ERROR## make command not defined" unless $make;
-
+  my $im_si;
   my $success = 1;
 
+  # save it for future use in ConfigData
+  $self->config_data('build_prefix', $prefixdir);
+  $self->config_data('debug_makeopts', $mopts);
+
   #create output directory structure
   mkdir "$prefixdir" unless -d "$prefixdir";
   mkdir "$prefixdir/lib" unless -d "$prefixdir/lib";
@@ -414,8 +301,14 @@ sub build_via_tecmake {
     print STDERR "Gonna build 'im'\n";
     chdir "$srcdir/im/src";
     foreach my $t (@{$imtgs}) {
-      $done{"im:$t"} = $self->run_custom($make, $t, @{$mopts});
-      $success = 0 unless $done{"im:$t"};
+      if ($self->notes('build_msgs')) {
+        $done{$t} = $self->run_output_std($make, $t, @{$mopts});
+      }
+      else {
+        $done{$t} = $self->run_output_on_error(undef, $make, $t, @{$mopts});
+      }
+      warn "###WARN### error [$?] during make $t" unless $done{$t};
+      $success = 0 unless $done{$t};
     }
     copy($_, "$prefixdir/include/") foreach (glob("../include/*.h"));
     copy($_, "$prefixdir/lib/") foreach (glob("../lib/*/*"));
@@ -426,8 +319,14 @@ sub build_via_tecmake {
     print STDERR "Gonna build 'cd'\n";
     chdir "$srcdir/cd/src";
     foreach my $t (@{$cdtgs}) {
-      $done{"cd:$t"} = $self->run_custom($make, $t, @{$mopts});
-      $success = 0 unless $done{"cd:$t"};
+      if ($self->notes('build_msgs')) {
+        $done{$t} = $self->run_output_std($make, $t, @{$mopts});
+      }
+      else {
+        $done{$t} = $self->run_output_on_error(undef, $make, $t, @{$mopts});
+      }
+      warn "###WARN### error [$?] during make $t" unless $done{$t};
+      $success = 0 unless $done{$t};
     }
     copy($_, "$prefixdir/include/") foreach (glob("../include/*.h"));
     copy($_, "$prefixdir/lib/") foreach (glob("../lib/*/*"));
@@ -438,18 +337,28 @@ sub build_via_tecmake {
     print STDERR "Gonna build 'iup'\n";
     chdir "$srcdir/iup";
     foreach my $t (@{$iuptgs}) {
-      $done{"iup:$t"} = $self->run_custom($make, $t, @{$mopts});
-      $success = 0 unless $done{"iup:$t"};
+      if ($self->notes('build_msgs')) {
+        $done{$t} = $self->run_output_std($make, $t, @{$mopts});
+      }
+      else {
+        $done{$t} = $self->run_output_on_error(undef, $make, $t, @{$mopts});
+      }
+      warn "###WARN### error [$?] during make $t" unless $done{$t};
+      $success = 0 unless $done{$t};
     }
     copy($_, "$prefixdir/include/") foreach (glob("./include/*.h"));
     copy($_, "$prefixdir/lib/") foreach (glob("./lib/*/*"));
     chdir $self->base_dir();
   }
 
-  # save it for future use in ConfigData
-  $self->config_data('build_prefix', $prefixdir);
-  $self->config_data('info_makeopts', $mopts);
-  $self->config_data('info_done', \%done);
+  unless ($done{iup} && $done{iupim} && $done{iupcd}) {
+    warn "###WARN### essential libs not built!";
+    $success = 0;
+  }
+
+  print STDERR "Done: $done{$_} - $_\n" foreach (sort keys %done);
+  $self->config_data('debug_done', \%done);
+  $self->config_data('debug_si', $im_si);
 
   return $success;
 }
@@ -460,23 +369,28 @@ sub get_make {
   my $devnull = File::Spec->devnull();
   my @try = ($Config{gmake}, 'gmake', 'make', $Config{make});
   my %tested;
-  print STDERR "Gonna detect GNU make\n" if $self->notes('build_debug_info');
+  print STDERR "Gonna detect GNU make:\n";
+
+  if ($^O eq 'cygwin') {
+    print STDERR "- on cygwin always 'make'\n";
+    return 'make'
+  }
 
   foreach my $name ( @try ) {
     next unless $name;
     next if $tested{$name};
     $tested{$name} = 1;
-    print STDERR "- testing: '$name'\n" if $self->notes('build_debug_info');
+    print STDERR "- testing: '$name'\n";
     my $ver = `$name --version 2> $devnull`;
     if ($ver =~ /GNU Make/i) {
-      print STDERR "- found: '$name'\n" if $self->notes('build_debug_info');
+      print STDERR "- found: '$name'\n";
       return $name
     }
   }
 
   warn "###WARN### it seems we do not have GNU make, build is likely gonna fail!";
   return;
-
+  
   #print STDERR "- fallback to: 'make'\n";
   #return 'make';
 }
