@@ -13,38 +13,50 @@ Alien::IUP - Building, finding and using iup + related libraries - L<http://www.
 
 =cut
 
-our $VERSION = "0.703_3";
+# following http://www.dagolden.com/index.php/369/version-numbers-should-be-boring/
+our $VERSION = "0.1000_01";
+$VERSION = eval $VERSION;
 
 =head1 VERSION
 
-Version 0.704 of Alien::IUP is based on the following:
+Version 0.1000_01 of Alien::IUP is based on the following:
 
 =over
 
-=item * I<iup> library 3.14 - see L<http://www.tecgraf.puc-rio.br/iup/>
+=item * I<iup> library 3.3 - see L<http://www.tecgraf.puc-rio.br/iup/>
 
-=item * I<im> library 3.9.1 - see L<http://www.tecgraf.puc-rio.br/im/>
+=item * I<im> library 3.6.3 - see L<http://www.tecgraf.puc-rio.br/im/>
 
-=item * I<cd> library 5.8.2 - see L<http://www.tecgraf.puc-rio.br/cd/>
+=item * I<cd> library 5.4.1 - see L<http://www.tecgraf.puc-rio.br/cd/>
 
 =back
 
 =head1 SYNOPSIS
 
 B<IMPORTANT:> This module is not a perl binding for I<iup + related> libraries; it is just
-a helper module. The real perl binding is implemented by L<IUP|IUP> module,
+a helper module. The real perl binding is implemented by L<IUP|http://github.com/kmx/perl-iup> module,
 which is using Alien::IUP to locate I<iup + related> libraries on your system (or build it from source codes).
 
-Alien::IUP installation comprise of:
+Alien::IUP tries (in given order) during its installation:
 
 =over
 
-=item * Downloading I<iup> & co. source code tarballs
+=item * Locate an already installed I<iup> and related libraries  + ask user whether
+to use the already installed I<iup> or whether to build I<iup> from sources
 
-=item * Building I<iup> & co. binaries from source codes (note: static libraries are build)
+=item * Via env variable IUP_DIR you can specify where the build script should look
+for the already installed I<iup> and related libs (directories $ENV{IUP_DIR}/lib and 
+$ENV{IUP_DIR}/include are expected to exist)
 
-=item * Installing libs and dev files (*.h, *.a) into I<share> directory of Alien::IUP
-distribution - I<share> directory is usually something like this: /usr/lib/perl5/site_perl/5.18/auto/share/dist/Alien-IUP
+=item * When not using the already installed libraries build process continues with
+the following steps
+
+=item * Download I<iup> & co. source code tarballs
+
+=item * Build I<iup> & co. binaries from source codes (note: static libraries are build in this case)
+
+=item * Install libs and dev files (*.h, *.a) into I<share> directory of Alien::IUP
+distribution - I<share> directory is usually something like this: /usr/lib/perl5/site_perl/5.10/auto/share/dist/Alien-IUP
 
 =back
 
@@ -63,7 +75,7 @@ I<iup> and/or related libs like this:
    # + additional params
  );
 
-B<IMPORTANT:> As Alien::IUP builds static libraries the modules using Alien::IUP (e.g. L<IUP|IUP>)
+B<IMPORTANT:> As Alien::IUP builds static libraries the modules using Alien::IUP (e.g. L<IUP|http://github.com/kmx/perl-iup>)
 need to have Alien::IUP just for building, not for later use. In other words Alien:IUP is just
 "build dependency" not "run-time dependency".
 
@@ -86,18 +98,6 @@ Returns a string like: '-I/path/to/iupdir/include'
 Returns a string like: '/path/to/iupdir' (note: if using the already installed
 I<iup> config('PREFIX') returns undef)
 
-=head2 havelib()
-
-Checks the presence of given iup related libraries.
-
- Alien::IUP->havelib('iupim');
- #or
- Alien::IUP->havelib('iupim', 'iupcd', 'iupcontrols');
-
-Parameter(s): One or more iup related lib names - e.g. iup, cd, im, iupcd, iupim, iupcontrols, iup_pplot, iupimglib, iupgl, iupole.
-
-Returns: 1 if all libs specified as a param are available; 0 otherwise.
-
 =head1 AUTHOR
 
 KMX, E<lt>kmx at cpan.orgE<gt>
@@ -105,14 +105,14 @@ KMX, E<lt>kmx at cpan.orgE<gt>
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-alien-iup at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Alien-IUP>.
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Alien-IUP>.
 
 =head1 LICENSE AND COPYRIGHT
 
-Libraries I<iup>, I<im> and I<cd>: Copyright (C) 1994-2015 Tecgraf, PUC-Rio.
+Libraries I<iup>, I<im> and I<cd>: Copyright (C) 1994-2010 Tecgraf, PUC-Rio.
 L<http://www.tecgraf.puc-rio.br>
 
-Alien::IUP module: Copyright (C) 2015 KMX.
+Alien::IUP module: Copyright (C) 2010 KMX.
 
 This program is distributed under the MIT License:
 L<http://www.opensource.org/licenses/mit-license.php>
@@ -140,13 +140,14 @@ OTHER DEALINGS IN THE SOFTWARE.
 
 =cut
 
-sub config {
+sub config
+{
   my ($package, $param) = @_;
   return unless ($param =~ /[a-z0-9_]*/i);
   my $subdir = Alien::IUP::ConfigData->config('share_subdir');
   unless ($subdir) {
     #we are using lib already installed on your system not compiled by Alien
-    #therefore no additional magic needed
+    #therefore no additinal magic needed
     return Alien::IUP::ConfigData->config('config')->{$param};
   }
   my $share_dir = dist_dir('Alien-IUP');
@@ -157,14 +158,4 @@ sub config {
   return $val;
 }
 
-sub havelib {
-  my ($package, @libs) = @_;
-  my $iuplibs = my $subdir = Alien::IUP::ConfigData->config('iup_libs');
-  return 0 unless defined $iuplibs;
-  for (@libs) {
-    return 0 unless defined $iuplibs->{$_} && $iuplibs->{$_} == 1;
-  }
-  return 1;
-}
-
 1; # End of Alien::IUP
